==> haskell-lift-type-0.1.2.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-IpckzE6foZ44z4MViUEZkR
key:                  lift-type-0.1.2.0-IpckzE6foZ44z4MViUEZkR
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  5a36aca00841ee50e3e07f1c00d1d2ef
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-IpckzE6foZ44z4MViUEZkR
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lift-type-0.1.2.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-2molXIZPA21BLO6X64paSQ
key:                  lift-type-0.1.2.0-2molXIZPA21BLO6X64paSQ
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  3bdd2b3ae0a82ee73b4ef319582c979e
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-2molXIZPA21BLO6X64paSQ
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
